@@ -1061,8 +1061,6 @@ class account():
                     status = self.api.PostUpdate(tweet, lat=self.lat, long=self.long)
                 else:
                     status = self.api.PostUpdate(tweet)
-            #update tweet count
-            self.setProfileInfo()
             return True
         except IOError, e:
             msg = 'Error posting tweet '
