@@ -1864,6 +1864,36 @@ class Api(object):
     self._CheckForTwitterError(data)
     return data
 
+  def GetLists(self, user):
+    '''Fetch users lists
+
+    The twitter.Api instance must be authenticated.
+
+    Returns:
+      json object with lists
+    '''
+    url = self._base_url + user+'/lists.json'
+    print url
+    json = self._FetchUrl(url)
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return data
+
+  def GetListMembers(self, user, listid):
+    '''Fetch members of lists
+
+    The twitter.Api instance must be authenticated.
+
+    Returns:
+      json object with members of specified list
+    '''
+    url = self._base_url + user+'/'+str(listid)+'/members.json'
+    print url
+    json = self._FetchUrl(url)
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return data
+
   def GetUser(self, user):
     '''Returns a single user.
 
